pub enum BroadcastFlags {
Local = 1,
Broadcast = 2,
Volatile = 4,
}Expand description
Flags that can be used to modify the behavior of the broadcast methods.
Variants
Local = 1
Broadcast only to the current server
Broadcast = 2
Broadcast to all clients except the sender
Volatile = 4
The event may be dropped if the client is not ready to receive it (e.g. the connection is buffering or not connected). This is useful for events that are not critical, like position updates in a game. See socket.io volatile events.