DefinedAdapter

Trait DefinedAdapter 

pub trait DefinedAdapter { }
A trait to add a “defined” bound to adapter types. This allow the socket io library to implement function given a defined adapter and not a generic A: Adapter.

This is useful to force the user to handle potential init response type CoreAdapter::InitRes.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors