RoomParam

Trait RoomParam 

pub trait RoomParam: Send + 'static {
    type IntoIter: Iterator<Item = Room>;

    // Required method
    fn into_room_iter(self) -> Self::IntoIter;
}
A trait for types that can be used as a room parameter.

String, Vec<String>, Vec<&str>, &'static str and const arrays are implemented by default.

Required Associated Types

type IntoIter: Iterator<Item = Room>

The type of the iterator returned by into_room_iter.

Required Methods

fn into_room_iter(self) -> Self::IntoIter

Convert self into an iterator of rooms.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl RoomParam for &'static str

Source

type IntoIter = Once<Cow<'static, str>>

Source

fn into_room_iter(self) -> Self::IntoIter

Source

impl RoomParam for &'static [&'static str]

Source

type IntoIter = Map<Iter<'static, &'static str>, fn(&'static &'static str) -> Cow<'static, str>>

Source

fn into_room_iter(self) -> Self::IntoIter

Source

impl RoomParam for String

Source

type IntoIter = Once<Cow<'static, str>>

Source

fn into_room_iter(self) -> Self::IntoIter

Source

impl RoomParam for Vec<&'static str>

Source

type IntoIter = Map<IntoIter<&'static str>, fn(&'static str) -> Cow<'static, str>>

Source

fn into_room_iter(self) -> Self::IntoIter

Source

impl RoomParam for Vec<String>

Source

impl RoomParam for Vec<Room>

Source

type IntoIter = IntoIter<Cow<'static, str>>

Source

fn into_room_iter(self) -> Self::IntoIter

Source

impl<const COUNT: usize> RoomParam for [&'static str; COUNT]

Source

type IntoIter = Map<IntoIter<&'static str, COUNT>, fn(&'static str) -> Cow<'static, str>>

Source

fn into_room_iter(self) -> Self::IntoIter

Source

impl<const COUNT: usize> RoomParam for [String; COUNT]

Source

type IntoIter = Map<IntoIter<String, COUNT>, fn(String) -> Cow<'static, str>>

Source

fn into_room_iter(self) -> Self::IntoIter

Implementors

Source

impl RoomParam for Sid

Source

type IntoIter = Once<Cow<'static, str>>

Source

impl RoomParam for Room

Source

type IntoIter = Once<Cow<'static, str>>