PartialBinPacket

Struct PartialBinPacket 

pub struct PartialBinPacket {
    pub packet: Packet,
    pub initial_packet_recv: Instant,
}
A partial binary packet along when we started receiving it.

Fields

packet: Packet

The packet whose we are waiting for its attachments

initial_packet_recv: Instant

When the initial packet is received, used in conjunction with ParseConfig::packet_completion_timeout.

Implementations

Source

impl PartialBinPacket

pub fn new(packet: Packet) -> Self

Create a new partial binary packet from a first Str Packet.