pub struct ParseConfig {
pub max_incoming_binary_buf_size: usize,
pub max_incoming_binaries: usize,
pub packet_completion_timeout: Duration,
}Expand description
A config passed to the parsers in order to securely decode packets
Fields
max_incoming_binary_buf_size: usizeMaximum buffer size of all the incoming binary attachments.
If the sum of each attachment exceeds this limit, the packet will be dropped and the connection closed.
Default to 10 MB
max_incoming_binaries: usizeMaximum number of incoming binary attachments.
If the incoming_binary_cnt is exceeded,
the packet will be dropped and the connection closed.
Default to 10_000
packet_completion_timeout: DurationTimeout after which it is no longer tolerable to wait for partial binary packets, the entire packet will dropped and the connection closed.
Default to 60 seconds