pub struct PartialBinPacket {
pub packet: Packet,
pub initial_packet_recv: Instant,
}Expand description
A partial binary packet along when we started receiving it.
Fields
packet: PacketThe packet whose we are waiting for its attachments
initial_packet_recv: InstantWhen the initial packet is received, used in conjunction
with ParseConfig::packet_completion_timeout.
Implementations